/*********************************************
 * OPL Model
 * Author: ILOG, Inc.
 * Creation Date: Fri November 25 16:31:50 2005
 *********************************************/

/****************** 
* Define the data *
******************/

{string} Products = { "sportsDrink", "classicDrink" };
{string} Machines = { "packer1", "packer2", "superPacker" };

float productionRate[Products][Machines] = [ [ 20, 40, 60 ], [ 10, 30, 50 ] ]; // production rate in cases/hr
float availability[Machines] = [ 104, 112, 120 ]; // machine availability in hours
float productionCost[Machines] = [ 50, 70, 110 ]; // hourly production cost
float demand[Products] = [ 3200, 2000 ]; // demand in cases

/********************************
* Define the decision variables *
********************************/

dvar int production[Products][Machines];  // production is now an integer variable
dvar float+ productionTime[Products][Machines]; 

dvar int numberShifts[Products][Machines];  // the number of shifts of production on each machine

dvar boolean chooseMachine[Machines];  // a boolean to indicate whether a packer is chosen or not

/******************************** 
* Define the objective function *
********************************/

// minimize the production cost
minimize
     sum(p in Products, m in Machines) (productionCost[m]*productionTime[p][m]);

/************************* 
* Define the constraints *
*************************/

subject to {
   // consider the production rate of each product on each machine
   forall(p in Products, m in Machines)
      rateConstraint: production[p][m] == productionRate[p][m] * productionTime[p][m];

   // the productionTime on a machine is forced to zero when that machine is not chosen
   forall(m in Machines)
      timeConstraint: sum(p in Products) productionTime[p][m] <= availability[m] * chooseMachine[m];

   // satisfy demand            
   forall(p in Products)
      demandConstraint: sum(m in Machines) production[p][m] >= demand[p];  
   
   // the numberShifts on a machine equals the total production time on that machine divided by 8
   forall(p in Products, m in Machines)
      shiftConstraint:  numberShifts[p][m] ==  productionTime[p][m] / 8.0;
      
   // logical constraints
   logic1: chooseMachine["superPacker"] + chooseMachine["packer1"] <= 1;
   logic2: chooseMachine["superPacker"] + chooseMachine["packer2"] <= 1;
   
   }



