/*********************************************
 * OPL Model
 * Author: ILOG, Inc.
 * Creation Date: Fri November 25 16:31:50 2005
 *********************************************/

/****************** 
* Define the data *
******************/

{string} Products = { "sportsDrink", "classicDrink" };

// add the new "superPacker" and associated data for productionRate, availability, and productionCost
{string} Machines = { "packer1", "packer2" };

float productionRate[Products][Machines] = [ [ 20, 40 ], [ 10, 30 ] ]; // production rate in cases/hr
float availability[Machines] = [ 104, 112 ]; // machine availability in hours
float productionCost[Machines] = [ 50, 70 ]; // hourly production cost
float demand[Products] = [ 3200, 2000 ]; // demand in cases

/********************************
* Define the decision variables *
********************************/

dvar int production[Products][Machines];  // production is now an integer variable
dvar float+ productionTime[Products][Machines]; 

dvar int numberShifts[Products][Machines];  // the number of shifts of production on each machine

// add a boolean decision variable, chooseMachine, to indicate whether a packer is chosen or not


/******************************** 
* Define the objective function *
********************************/

// minimize the production cost
minimize
     sum(p in Products, m in Machines) (productionCost[m]*productionTime[p][m]);

/************************* 
* Define the constraints *
*************************/

subject to {
   // consider the production rate of each product on each machine
   forall(p in Products, m in Machines)
      rateConstraint: production[p][m] == productionRate[p][m] * productionTime[p][m];

   // use chooseMachine to force the productionTime to zero when the machine is not chosen
   forall(m in Machines)
      timeConstraint: sum(p in Products) productionTime[p][m] <= availability[m] ;

   // satisfy demand            
   forall(p in Products)
      demandConstraint: sum(m in Machines) production[p][m] >= demand[p];  
   
   // the numberShifts on a machine equals the total production time on that machine divided by 8
   forall(p in Products, m in Machines)
      shiftConstraint:  numberShifts[p][m] ==  productionTime[p][m] / 8.0;
   
   // add two logical constraints to the effect that choosing superPacker implies not choosing packer1 and packer2, and vice versa.
      
}



