/*********************************************
 * OPL Model
 * Author: ILOG, Inc.
 * Creation Date: Fri November 25 16:31:50 2005
 *********************************************/

/****************** 
* Define the data *
******************/

{string} Products = { "sportsDrink", "classicDrink" };
{string} Machines = { "packer1", "packer2" };

float productionRate[Products][Machines] = [ [ 20, 40 ], [ 10, 30 ] ]; // production rate in cases/hr
float availability[Machines] = [ 104, 112 ]; // machine availability in hours
float productionCost[Machines] = [ 50, 70 ]; // hourly production cost
float demand[Products] = [ 3200, 2000 ]; // demand in cases

/********************************
* Define the decision variables *
********************************/

dvar float+ production[Products][Machines];  // production of product p on machine m

// Define a variable for productionTime of product p on machine m   

/******************************** 
* Define the objective function *
********************************/

// minimize the total production cost
minimize
     sum(p in Products, m in Machines) (productionCost[m]*productionTime[p][m]);


/************************* 
* Define the constraints *
*************************/

subject to {
   // consider the production rate of each product on each machine
   forall(p in Products, m in Machines)
      rateConstraint: production[p][m] == productionRate[p][m] * productionTime[p][m];


   // do not exceed the available time
   forall(m in Machines)
      timeConstraint:  ;

   // satisfy demand            
   forall(p in Products)
      demandConstraint: ;  
   
}



