/*********************************************
 * OPL Model
 * Author: ILOG, Inc.
 * Creation Date: Fri November 25 16:31:50 2005
 *********************************************/

/****************** 
* Define the data *
******************/

{string} Products = { "sportsDrink", "classicDrink" };
{string} Machines = { "packer1", "packer2" };

float productionRate[Products][Machines] = [ [ 20, 40 ], [ 10, 30 ] ]; // production rate in cases/hr
float availability[Machines] = [ 104, 112 ]; // machine availability in hours
float productionCost[Machines] = [ 50, 70 ]; // hourly production cost
float demand[Products] = [ 5000, 3500 ]; // demand in cases

float penalty[Products] = [100, 500];

/********************************
* Define the decision variables *
********************************/

dvar int production[Products][Machines];  // production is now an integer variable
dvar float+ productionTime[Products][Machines]; 

dvar int numberShifts[Products][Machines];  // the number of shifts of production on each machine

dvar float+ unsatisfiedDemand[Products];

/******************************** 
* Define the objective function *
********************************/

// minimize the production cost
minimize
     sum(p in Products, m in Machines) (productionCost[m]*productionTime[p][m])
     + sum(p in Products) penalty[p] * unsatisfiedDemand[p]; // penalty term for unsatisfied demand
/************************* 
* Define the constraints *
*************************/

subject to {
   // consider the production rate of each product on each machine
   forall(p in Products, m in Machines)
      rateConstraint: production[p][m] == productionRate[p][m] * productionTime[p][m];

   // do not exceed the available time
   forall(m in Machines)
      timeConstraint: sum(p in Products) productionTime[p][m] <= availability[m] ;

   // satisfy demand            
   forall(p in Products)
      demandConstraint: sum(m in Machines) production[p][m] >= demand[p] - unsatisfiedDemand[p];
   
   // the numberShifts on a machine equals the total production time on that machine divided by 8
   forall(p in Products, m in Machines)
      shiftConstraint:  numberShifts[p][m] ==  productionTime[p][m] / 8.0;
      
}



